==> mmsmsretriever-0.0.1.tar.gz: android/src/main/kotlin/com/htetwaiyan/mmsmsretriever/MmsmsretrieverPlugin.kt <==
package com.htetwaiyan.mmsmsretriever

import android.app.Activity
import android.content.IntentFilter
import android.support.v4.content.LocalBroadcastManager
import com.google.android.gms.auth.api.phone.SmsRetriever
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

class MmsmsretrieverPlugin(var  channel:MethodChannel,var  activity: Activity): MethodCallHandler , SMSReceiver.OTPReceiveListener {
  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "mmsmsretriever")
      channel.setMethodCallHandler(MmsmsretrieverPlugin(channel,registrar.activity()))
    }
  }

  var smsReceiver:SMSReceiver?=null


  override fun onMethodCall(call: MethodCall, result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    }else if(call.method=="startListen"){
      val appSignatureHashHelper = AppSignatureHashHelper(activity)
      result.success("Apps Hash Key: "+ appSignatureHashHelper.appSignatures[0])
      startSMSListener()
    }
    else {
      result.notImplemented()
    }
  }



  private fun startSMSListener() {
    try {
      smsReceiver = SMSReceiver()
      smsReceiver!!.setOTPListener(this)

      val intentFilter = IntentFilter()
      intentFilter.addAction(SmsRetriever.SMS_RETRIEVED_ACTION)
      activity.registerReceiver(smsReceiver, intentFilter)

      val client = SmsRetriever.getClient(activity)

      val task = client.startSmsRetriever()
      task.addOnSuccessListener {
        // API successfully started
      }

      task.addOnFailureListener {
        // Fail to start API
      }
    } catch (e: Exception) {
      e.printStackTrace()
    }

  }


  override fun onOTPReceived(otp: String) {
    showToast("OTP Received: $otp")

    channel.invokeMethod("otpcode",otp)

    if (smsReceiver != null) {
      LocalBroadcastManager.getInstance(activity).unregisterReceiver(smsReceiver)
    }
  }

  override  fun onOTPTimeOut() {
    showToast("OTP Time out")
  }

  override  fun onOTPReceivedError(error: String) {
    showToast(error)
  }


  fun onDispose() {
    if (smsReceiver != null) {
      LocalBroadcastManager.getInstance(activity).unregisterReceiver(smsReceiver)
    }
  }


  private fun showToast(msg: String) {

  }

}

==> mmsmsretriever-0.0.2.tar.gz: android/src/main/kotlin/com/htetwaiyan/mmsmsretriever/MmsmsretrieverPlugin.kt <==
package com.htetwaiyan.mmsmsretriever

import android.app.Activity
import android.content.IntentFilter
import android.support.v4.content.LocalBroadcastManager
import com.google.android.gms.auth.api.phone.SmsRetriever
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

class MmsmsretrieverPlugin(var  channel:MethodChannel,var  activity: Activity): MethodCallHandler , SMSReceiver.OTPReceiveListener {
  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "com.htetwaiyan.mmsmsretriever")
      channel.setMethodCallHandler(MmsmsretrieverPlugin(channel,registrar.activity()))
    }
  }

  var smsReceiver:SMSReceiver?=null


  override fun onMethodCall(call: MethodCall, result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    }else if(call.method=="startListen"){
      val appSignatureHashHelper = AppSignatureHashHelper(activity)
      result.success("Apps Hash Key: "+ appSignatureHashHelper.appSignatures[0])
      startSMSListener()
    }
    else {
      result.notImplemented()
    }
  }



  private fun startSMSListener() {
    try {
      smsReceiver = SMSReceiver()
      smsReceiver!!.setOTPListener(this)

      val intentFilter = IntentFilter()
      intentFilter.addAction(SmsRetriever.SMS_RETRIEVED_ACTION)
      activity.registerReceiver(smsReceiver, intentFilter)

      val client = SmsRetriever.getClient(activity)

      val task = client.startSmsRetriever()
      task.addOnSuccessListener {
        // API successfully started
      }

      task.addOnFailureListener {
        // Fail to start API
      }
    } catch (e: Exception) {
      e.printStackTrace()
    }

  }


  override fun onOTPReceived(otp: String) {
    showToast("OTP Received: $otp")

    channel.invokeMethod("otpcode",otp)

    if (smsReceiver != null) {
      LocalBroadcastManager.getInstance(activity).unregisterReceiver(smsReceiver)
    }
  }

  override  fun onOTPTimeOut() {
    showToast("OTP Time out")
  }

  override  fun onOTPReceivedError(error: String) {
    showToast(error)
  }


  fun onDispose() {
    if (smsReceiver != null) {
      LocalBroadcastManager.getInstance(activity).unregisterReceiver(smsReceiver)
    }
  }


  private fun showToast(msg: String) {

  }

}
